==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/attributes/attributes/top/yangautoprefixinterface/DefaultAddress.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.attributes.attributes.top.yangautoprefixinterface;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of address.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAddress extends InnerModelObject implements Address {
    protected String name;
    protected String prefixLength;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String name() {
        return name;
    }

    @Override
    public String prefixLength() {
        return prefixLength;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void name(String name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void prefixLength(String prefixLength) {
        valueLeafFlags.set(LeafIdentifier.PREFIXLENGTH.getLeafIndex());
        this.prefixLength = prefixLength;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, prefixLength, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAddress) {
            DefaultAddress other = (DefaultAddress) obj;
            return
                Objects.equals(name, other.name) &&
                Objects.equals(prefixLength, other.prefixLength) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("name=" + name)
            .add("prefixLength=" + prefixLength)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAddress.
     */
    public DefaultAddress() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/attributes/attributes/top/yangautoprefixinterface/DefaultAddress.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.attributes.attributes.top.yangautoprefixinterface;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of address.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAddress extends InnerModelObject implements Address {
    protected String name;
    protected String prefixLength;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String name() {
        return name;
    }

    @Override
    public String prefixLength() {
        return prefixLength;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void name(String name) {
        valueLeafFlags.set(LeafIdentifier.NAME.getLeafIndex());
        this.name = name;
    }

    @Override
    public void prefixLength(String prefixLength) {
        valueLeafFlags.set(LeafIdentifier.PREFIXLENGTH.getLeafIndex());
        this.prefixLength = prefixLength;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, prefixLength, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAddress) {
            DefaultAddress other = (DefaultAddress) obj;
            return
                Objects.deepEquals(name, other.name) &&
                Objects.deepEquals(prefixLength, other.prefixLength) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("name=" + name)
            .add("prefixLength=" + prefixLength)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAddress.
     */
    public DefaultAddress() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
